diff sat/tools/common/template.py @ 2877:f8427bf8c072

tools (common/template): always use highlight.css if present.
author Goffi <goffi@goffi.org>
date Mon, 25 Mar 2019 18:40:11 +0100
parents 003b8b4b56a7
children 68a7543ebbb3
line wrap: on
line diff
--- a/sat/tools/common/template.py	Mon Mar 25 18:40:10 2019 +0100
+++ b/sat/tools/common/template.py	Mon Mar 25 18:40:11 2019 +0100
@@ -560,7 +560,8 @@
         For each element of the path, a .css file is looked for in /static, and returned
         if it exists.
         Previous element are kept by replacing '/' with '_'.
-        styles_extra.css, styles.css and fonts.css are always used if they exist.
+        styles_extra.css, styles.css, highlight.css and fonts.css are always used if they
+            exist.
         For each found file, if a file with the same name and "_noscript" suffix exists,
         it will be return is second part of resulting tuple.
         For instance, if template_data is (some_site, some_theme, blog/articles.html),
@@ -589,7 +590,7 @@
         if css_path is not None:
             css_files.append(self.getFrontURL(css_path))
 
-        for name_root in (u'styles', u'styles_extra'):
+        for name_root in (u'styles', u'styles_extra', u'highlight'):
             self._appendCSSPaths(template_data, css_files, css_files_noscript, name_root)
 
         for idx in xrange(len(path_elems)):